# ProductRatePlanChargeObjectNSFieldsRevRecStartNS

Start date condition of the corresponding item in NetSuite. Only available if you have installed the [Zuora Connector for NetSuite](https://www.zuora.com/connect/app/?appId=265). 

## Enum

* `CHARGE_PERIOD_START` (value: `'Charge Period Start'`)

* `REV_REC_TRIGGER_DATE` (value: `'Rev Rec Trigger Date'`)

* `USE_NETSUITE_REV_REC_TEMPLATE` (value: `'Use NetSuite Rev Rec Template'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


